@@ -48,7 +48,7 @@ def country_list_is_valid(
     for country in onlycountry:
         if country not in countrylist:
             util.msg(
-                message=f"{txt.OPTION}{txt.OPT_COUNTRY}: {txt.OPT_COUNTRY}: '{txt.UNKNOWN_COUNTRY}'",
+                message=f"{txt.OPTION}{txt.OPT_COUNTRY}: {txt.UNKNOWN_COUNTRY} '{country}'",
                 urgency=txt.WRN_CLR,
                 tty=tty,
             )
